@@ -180,7 +180,7 @@ class Core():
             with open(pd_file, "wb") as f:
                 pickle.dump(data, f)
         elif self.output_file_type == self.FileTypes.JSON:
-            data.to_json(pd_file)
+            data.to_json(pd_file, indent=2)
     
     def get_pandas_data_frame(self, filename:str) -> Union[pd.DataFrame,None]:
         """    
@@ -213,7 +213,7 @@ class Core():
         else:
             return None
               
-    def get_pandas_data_frame_path(self, filename:str) -> Union[str,None]:
+    def get_pandas_data_frame_path(self, filename:str) -> Union[Path,None]:
         """    
         Get a pandas DataFrame path from the project directory.
         The project metadata will be excessed from the top level directory.
@@ -226,7 +226,7 @@ class Core():
     
         Returns
         -------
-        str
+        Path
             Return a str path of the feature.
         None
             Return None because the file does not exists.
@@ -237,7 +237,7 @@ class Core():
         else:
             pd_file = Path(self.project_data_dir, filename + self.input_file_type)
         if pd_file.is_file():
-            return str(pd_file)
+            return pd_file
         else:
             return None
 
