@@ -569,11 +569,11 @@ class Extractions(Core):
         else:
             # ToDo: Check if there are redudant information
             for key, value in buffer.items():
-                if key == self.Features.BRANCHES or key == self.Features.ISSUE_BOARDS or key == self.Features.ISSUE_BOARDS_LISTS or key == self.Features.LABELS or key == self.Features.USERS:
+                if key == self.Features.WIKIS or key == self.Features.BRANCHES or key == self.Features.ISSUE_BOARDS or key == self.Features.ISSUE_BOARDS_LISTS or key == self.Features.LABELS or key == self.Features.USERS:
                     self.save_as_pandas(key,pd.DataFrame(value))
                 else:
                     feature_df = self.get_pandas_data_frame(key)
-                    new_df = pd.concat([feature_df,pd.DataFrame(value)], ignore_index=True, sort=False)
+                    new_df = pd.concat([pd.DataFrame(value),feature_df], ignore_index=True)
                     if "iid" in new_df:
                         new_df = new_df.drop_duplicates(subset=['iid'])
                     elif "id" in new_df:
@@ -581,6 +581,7 @@ class Extractions(Core):
                     else:
                         print(f"Ids not found in {key}. Might not drop duplicates")
                         new_df = new_df.drop_duplicates()
+                    new_df.reset_index()
                     self.save_as_pandas(key,new_df)
 
     def __gitlab_data_producer(self, gitlab_obj, feature_name:str, value, is_sub_function:bool = False) -> None:
