@@ -23,4 +23,8 @@ class GitLab2Pandas(Core):
         extractions = Extractions(self.data_root_dir, 
                                     project=self.project,
                                     extract_parallel=extract_parallel)
+        if self.input_file_type != self.FileTypes.PANDAS:
+            extractions.set_input_type(self.input_file_type)
+        if self.output_file_type != self.FileTypes.PANDAS:
+            extractions.set_output_type(self.output_file_type)
         extractions.start(feature_blacklist, feature_whitelist, update)
\ No newline at end of file
